%bcond docs 1
%bcond introspection 1

# The shared library version
%global soversion 0.5

Name:           libipuz
Version:        0.5.2
Release:        1.20250418061953180528.master.57.g3b8b788%{?dist}
Summary:        Library for parsing .ipuz puzzle files

License:        LGPL-2.1-or-later OR MIT
URL:            https://gitlab.gnome.org/jrb/libipuz
Source:         libipuz-0.5.2.tar.gz
# rust: bump glib to 0.19.5
# rust: bump glib to 0.20

BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  python3
BuildRequires:  sed
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(myst-parser)
%endif

BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
%if %{with introspection}
BuildRequires:  gi-docgen
BuildRequires:  gobject-introspection-devel
%endif

%description
This is a library for parsing .ipuz puzzle files, for crossword puzzles,
sudokus, etc. The library only handles crosswords for now.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with docs}
Suggests:       %{name}-doc = %{version}-%{release}
%endif

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with docs}
%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
This package contains additional documentation for %{name}.
%endif

%package        tests
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    tests
The %{name}-tests package contains tests for %{name}.

%prep
%autosetup -p1 -n libipuz-0.5.2
%cargo_prep

# Drop version locks
rm libipuz/rust/Cargo.lock
sed -i '/Cargo.lock/d' libipuz/rust/meson.build

%generate_buildrequires
cd libipuz/rust
%cargo_generate_buildrequires

%build
%meson
%meson_build

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%meson_install

%check
%meson_test

%files
%license LICENSE COPYING.LGPL COPYING.MIT
%doc README.md NEWS.md
%{_libdir}/lib%{name}-%{soversion}.so

%files devel
%{_includedir}/*
%if %{with introspection}
%{_datadir}/gir-1.0/Ipuz-1.0.gir
%{_libdir}/girepository-1.0/Ipuz-1.0.typelib
%endif
%{_libdir}/pkgconfig/%{name}-%{soversion}.pc

%if %{with docs}
%files doc
%license LICENSE COPYING.LGPL COPYING.MIT
%doc html
%if %{with introspection}
%doc %{_docdir}/%{name}-1.0/
%endif
%endif

%files tests
%dir %{_datadir}/installed-tests
%{_datadir}/installed-tests/%{name}-1.0
%dir %{_libexecdir}/installed-tests
%{_libexecdir}/installed-tests/%{name}-1.0

%changelog
* Fri Apr 18 2025 Packit <hello@packit.dev> - 0.5.2-1.20250418061953180528.master.57.g3b8b788
- Minor doc update (Jonathan Blandford)
- MIRRORED_DIAGONAL and MIRRORED_DIAGONAL_UP_RIGHT can't be non-square (Jonathan Blandford)
- Use lowercase "x" for cross divider (Victor Ma)
- We need to write "" when we have an empty block. (Jonathan Blandford)
- rust.md: Note on how to convert filenames from C to Rust (Federico Mena Quintero)
- guesses.rs: Convert filenames from C to Rust correctly (Federico Mena Quintero)
- guesses.rs: Use GString and GStr instead of CString and CStr (Federico Mena Quintero)
- charset.rs: Use GStr instead of CStr (Federico Mena Quintero)
- enumeration.rs: Use GStr instead of CStr (Federico Mena Quintero)
- Notes on glib::GString and GStr (Federico Mena Quintero)
- Add test for ipuz_puzzle_game_won for nonograms (Philip Chimento)
- Adjust check_cell logic for nonograms (Philip Chimento)
- Set the cell type to normal when you guess null or a space (Philip Chimento)
- Set the cell_type to block when you call set_guess() with "#" (Jonathan Blandford)
- Use a temporary variable for the conversion from CStr to &str (Federico Mena Quintero)
- A bit less ugly (Federico Mena Quintero)
- Fix mutable borrows the ugly way (Federico Mena Quintero)
- Still broken. Syncing with Federico (Jonathan Blandford)
- Pushing a broken version (Jonathan Blandford)
- Change the "#" default block to a member of the Guesses struct (Jonathan Blandford)
- Add HAS_SOLUTION flag to all nonogram puzzles (Philip Chimento)
- Fix typecheck in ipuz_grid_game_won (Philip Chimento)
- Increase rust tests timeout to 60s (Vinson Lee)
- Remove check_clue_first_letter() (Jonathan Blandford)
- Simplify initialize_answers significantly() (Jonathan Blandford)
- Use a better g_return_if_fail checks (Jonathan Blandford)
- New method: ipuz_acrostic_clear_answers() (Jonathan Blandford)
- Remove println! (Jonathan Blandford)
- Add another assertion to the tests (Jonathan Blandford)
- Don't set the clues in ipuz_acrostic_init () (Jonathan Blandford)
- New function: ipuz_acrostic_initialize_answers() (Jonathan Blandford)
- rewrite sync_source_to_clues() (Jonathan Blandford)
- Initialize the clueset on instance init (Jonathan Blandford)
- Use new ipuz_clues_unlink_clue() function (Jonathan Blandford)
- Move normalized source check to the top of the function (Jonathan Blandford)
- Add a missing g_return_if_fail (Jonathan Blandford)
- Add docs for get_normalized_quote/source() (Jonathan Blandford)
- Add some warnings to IpuzClue functions (Jonathan Blandford)
- Add ipuz_clues_unlink_clue() (Jonathan Blandford)
- Bring back get_normalized_source/quote() (Jonathan Blandford)
- Update acrostic docs (Jonathan Blandford)
- Fix admonition. (Jonathan Blandford)
- Test add_answer() (Jonathan Blandford)
- Clear the old clue when setting an answer (Jonathan Blandford)
- Fix ipuz_crossword_print() to work while in the tests (Jonathan Blandford)
- Inital set_answer() implementation (Jonathan Blandford)
- Reorder ipuz-acrostic to match the order (Jonathan Blandford)
- New function: ipuz_charset_subset() (Jonathan Blandford)
- Update docs for ipuz_acrostic_fix_labels (Jonathan Blandford)
- Add an argument to ipuz_acrostic_fix_labels() (Jonathan Blandford)
